Agents
======

DQN
---

.. autoclass:: ai_traineree.agents.dqn.DQNAgent
    :members:
    :undoc-members:

Rainbow
-------

.. autoclass:: ai_traineree.agents.rainbow.RainbowAgent
    :members:
    :undoc-members:


PPO
---

.. autoclass:: ai_traineree.agents.ppo.PPOAgent
    :members:
    :undoc-members:


DDPG
----

.. autoclass:: ai_traineree.agents.ddpg.DDPGAgent
    :members:
    :undoc-members:

D3PG
----

.. autoclass:: ai_traineree.agents.d3pg.D3PGAgent
    :members:
    :undoc-members:

D4PG
----

.. autoclass:: ai_traineree.agents.d4pg.D4PGAgent
    :members:
    :undoc-members:
    
SAC
---

.. autoclass:: ai_traineree.agents.sac.SACAgent
    :members:
    :undoc-members:
   